@@ -1,8 +1,6 @@
-pub use config::GlobalConfig;
+pub use self::config::{CssProcessor, GlobalConfig};
 pub use tailwind_error::{Result, TailwindError};
 
-pub use self::processor::CssProcessor;
-
 mod config;
 mod processor;
 mod support;
